@@ -90,6 +90,7 @@ class MigrationConfig(object):
             hosts=None,
             indexes=None,
             query=None,
+            scroll="1d",
             time_reference=None,
             logstore_index_mappings=None,
             source=None,
@@ -114,6 +115,7 @@ class MigrationConfig(object):
                 'hosts': hosts,
                 'indexes': indexes,
                 'query': query,
+                'scroll': scroll,
                 'logstore_index_mappings': logstore_index_mappings,
                 'source': source,
                 'topic': topic,
@@ -138,6 +140,7 @@ class MigrationConfig(object):
                 'hosts': hosts,
                 'indexes': indexes,
                 'query': query,
+                'scroll': scroll,
                 'time_reference': time_reference,
                 'logstore_index_mappings': logstore_index_mappings,
                 'source': source,
@@ -284,10 +287,11 @@ class MigrationManager(object):
             os.unlink(self._shutdown_flag)
 
         def _handle_term_sig(signum, frame):
-            # Raise Ctrl+C
+            msg = "termination signal received, exiting..."
+            print(msg)
+            _logger.info(msg)
             with open(self._shutdown_flag, 'w') as f:
                 f.write('')
-            raise KeyboardInterrupt()
 
         signal.signal(signal.SIGINT, _handle_term_sig)
         signal.signal(signal.SIGTERM, _handle_term_sig)
@@ -420,7 +424,7 @@ def _migration_worker(config, task, shutdown_flag, es_version):
         'es_shard': task['es_shard'],
         'logstore': task['logstore'],
     }
-    print('migrate:', json.dumps(extra))
+    print('migrate:' + json.dumps(extra))
     logger = PrefixLoggerAdapter('', extra, _logger, {})
     logger.info('Migration worker starts')
     try:
@@ -450,8 +454,10 @@ def _migration_worker(config, task, shutdown_flag, es_version):
             batch_size=config.get('batch_size'),
             logger=logger,
             es_version=es_version,
+            es_query=config.get('query'),
+            es_scroll=config.get('scroll'),
         )
-        return task.run()
+        return task.run(shutdown_flag)
     except BaseException:
         logger.error(
             'Exception in migration worker',
